diff src/xterm.h @ 25466:7057ab217315

(FRAME_X_FLAGS_AREA_COLS): Define it as the total width of both margins. (FRAME_X_FLAGS_AREA_WIDTH): Likewise. (FRAME_X_LEFT_FLAGS_AREA_WIDTH): New. (FRAME_X_RIGHT_FLAGS_AREA_WIDTH): New.
author Gerd Moellmann <gerd@gnu.org>
date Mon, 30 Aug 1999 23:14:40 +0000
parents 7505930b5456
children c19107a5df88
line wrap: on
line diff
--- a/src/xterm.h	Mon Aug 30 23:14:36 1999 +0000
+++ b/src/xterm.h	Mon Aug 30 23:14:40 1999 +0000
@@ -630,19 +630,34 @@
 #define FRAME_FLAGS_BITMAP_WIDTH(f)	8
 #define FRAME_FLAGS_BITMAP_HEIGHT(f)	8
 
 /* Width of a single area reserved for drawing truncation bitmaps,
    continuation bitmaps and alike.  The width is in canonical char
    units of the frame.  This must currently be the case because window
    sizes aren't pixel values.  If it weren't the case, we wouldn't be
    able to split windows horizontally nicely.  */
 
-#define FRAME_X_FLAGS_AREA_COLS(F)				\
-     ((FRAME_FLAGS_BITMAP_WIDTH ((F)) + CANON_X_UNIT ((F)) - 1)	\
+#define FRAME_X_FLAGS_AREA_COLS(F)					\
+     ((2 * FRAME_FLAGS_BITMAP_WIDTH ((F)) + CANON_X_UNIT ((F)) - 1)	\
       / CANON_X_UNIT ((F)))
 
+/* Total width of flags areas in pixels.  */
+
 #define FRAME_X_FLAGS_AREA_WIDTH(F) \
      (FRAME_X_FLAGS_AREA_COLS ((F)) * CANON_X_UNIT ((F)))
 
+/* Pixel-width of the left flags area.  */
+
+#define FRAME_X_LEFT_FLAGS_AREA_WIDTH(F) \
+     (FRAME_X_FLAGS_AREA_WIDTH (F) / 2)
+
+/* Pixel-width of the right flags area.  Note that we are doing
+   integer arithmetic here, so don't loose a pixel if the total
+   width is an odd number.  */
+
+#define FRAME_X_RIGHT_FLAGS_AREA_WIDTH(F) 	\
+     (FRAME_X_FLAGS_AREA_WIDTH (F) - FRAME_X_FLAGS_AREA_WIDTH (F) / 2)
+
+
 
 /* X-specific scroll bar stuff.  */
@@ -630,19 +630,34 @@
 #define FRAME_FLAGS_BITMAP_HEIGHT(f)	8
 
-/* Width of a single area reserved for drawing truncation bitmaps,
+/* Total width of a areas reserved for drawing truncation bitmaps,
    continuation bitmaps and alike.  The width is in canonical char
    units of the frame.  This must currently be the case because window